@@ -1,7 +1,7 @@
 /*
- *  Copyright (C) 2014-2018 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ *  Copyright (C) 2013-2019 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2009-2013 Sourcefire, Inc.
- *  All rights reserved.
+
  *  Authors: Török Edvin, Kevin Lin
  *
  * Redistribution and use in source and binary forms, with or without
@@ -114,9 +114,11 @@ enum FunctionalityLevels {
     FUNC_LEVEL_0100_0    = 91, /* LibClamAV release 0.100.0, 0.100.0-rc */
     FUNC_LEVEL_0100_1    = 92, /**< LibClamAV release 0.100.1 */
     FUNC_LEVEL_0100_2    = 93, /**< LibClamAV release 0.100.2 */
+    FUNC_LEVEL_0100_3    = 94, /**< LibClamAV release 0.100.3 */
     FUNC_LEVEL_0101_0_BETA = 100, /* LibClamAV beta release 0.101.0-beta */
     FUNC_LEVEL_0101_0    = 101, /* LibClamAV release 0.101.0, 0.101.0-rc */
     FUNC_LEVEL_0101_1    = 102, /* LibClamAV release 0.101.1 */
+    FUNC_LEVEL_0101_2    = 103, /* LibClamAV release 0.101.3 */
     FUNC_LEVEL_100       = 255 /* future release candidate */
 };
 
